@@ -24,6 +24,13 @@ my @known_categories = ( qw(LC_ALL LC_COLLATE LC_CTYPE LC_MESSAGES LC_MONETARY
                             LC_TOD));
 my @platform_categories;
 
+sub is_category_valid($) {
+    my $cat_name = shift =~ s/^LC_//r;
+
+    # Recognize Configure option to exclude a category
+    return $Config{ccflags} !~ /\bD?NO_LOCALE_$cat_name\b/;
+}
+
 # LC_ALL can be -1 on some platforms.  And, in fact the implementors could
 # legally use any integer to represent any category.  But it makes the most
 # sense for them to have used small integers.  Below, we create new locale
@@ -205,7 +212,7 @@ sub valid_locale_categories() {
     # Returns a list of the locale categories (expressed as strings, like
     # "LC_ALL) known to this program that are available on this platform.
 
-    return @platform_categories;
+    return grep { is_category_valid($_) } @platform_categories;
 }
 
 sub locales_enabled(;$) {
@@ -310,8 +317,9 @@ sub locales_enabled(;$) {
                     unless defined $number;
             }
 
-            return 0 if    $number <= $max_bad_category_number
-                        || $Config{ccflags} =~ /\bD?NO_LOCALE_$name\b/;
+            return 0 if     $number <= $max_bad_category_number
+                       || ! is_category_valid($name);
+
 
             eval "defined &POSIX::LC_$name";
             return 0 if $@;
@@ -377,12 +385,9 @@ sub find_locales ($;$) {
     # so re-enable the tests for Windows XP onwards.
     my $winxp = ($^O eq 'MSWin32' && defined &Win32::GetOSVersion &&
                     join('.', (Win32::GetOSVersion())[1..2]) >= 5.1);
-    return if ((($^O eq 'MSWin32' && !$winxp) || $^O eq 'NetWare')
+    return if (($^O eq 'MSWin32' && !$winxp)
                 && $Config{cc} =~ /^(cl|gcc|g\+\+|ici)/i);
 
-    # UWIN seems to loop after taint tests, just skip for now
-    return if ($^O =~ /^uwin/);
-
     my @Locale;
     _trylocale("C", \@categories, \@Locale, $allow_incompatible);
     _trylocale("POSIX", \@categories, \@Locale, $allow_incompatible);
